define('components/keyboard/1.0.0/js/keyboard', function() {
    var noop = function() {};
    var defaultOpts = {
        containsID: "keyboardBox",
        id: "password",
        inputType: "password",
        type: "1",
        defaultValue: "",
        maxLength: "40",
        placeholder: " ",
        focus: noop,
        blur: noop,
        press: noop,
        complete: noop,
        css: {
            "width": "100%;",
            "height": "35px;",
            "line-height": "35px;",
            "font-size": "17px;",
            "color": "#ccc;",
            "border": "1px solid #aaa;",
            "border-radius": "5px;",
            "outline": "none;",
            "margin-top": "5px;",
            "text-indent": "8px;",
            "padding-right": "5px;"
        }
    };
    var isAndroid = navigator.userAgent.indexOf('Android') !== -1;
    var keyboard = function(options) {
        var opts = options;
        this.containsID = $("#" + opts.containsID) || "";//键盘创建的容器
        this.body = $("body");
        this.defaultValue = opts.defaultValue || "";//键盘默认值
        this.maxLength = opts.maxLength || defaultOpts.maxLength;//键盘可输入的最大长度
        this.type = opts.type || defaultOpts.type;//弹出键盘的类别
        this.inputType = opts.inputType || defaultOpts.inputType;//input输入框的内容
        this.placeholder = opts.placeholder || defaultOpts.placeholder;//设置输入框的platerholder
        this.id = opts.id;//input password的ID名称
        this.press = opts.press || function() {};//键盘press事件
        this.complete = opts.complete || function() {};//键盘点击完成事件
        this.focus = opts.focus || function() {};//input focus事件
        this.blur = opts.blur || function() {};//input blur完成事件
        this.css = $.extend({}, defaultOpts.css, opts.css); //初始化键盘输入框样式
        this.init();//初始化键盘
    };
    keyboard.prototype = {
        init: function() {//初始化键盘
            var self = this;
            self.render();
            self.bindEvents();
        },
        view: function() {//键盘的模型
            var self = this, pwdID = self.id,inputType = self.inputType,html = "",placeholder = self.placeholder;
            if (isAndroid) {
                inputType = "hidden";
                html = '<div class ="keyboard-wrap keyboard-wrap' + pwdID + '">' +
                    '<input type ="' + inputType + '"  class="' + pwdID + '" id= "' + pwdID + '" placeholder = "' + placeholder + '" />' +
                    '<div class="keyboard-wrap-layer keyboard-wrap-layer-' + pwdID + '" data-id="' + pwdID + '" data-type="' + inputType + '">' +
                    '</div>' +
                '</div>';
            } else {
                html = '<div class ="keyboard-wrap">' +
                    '<input type ="' + inputType + '"  class="' + pwdID + '" id= "' + pwdID + '" placeholder = "' + placeholder + '" />' +
                '</div>';
            }
            return html;
        },
        render: function() {//初始化渲染dom
            var self = this, containsID = self.containsID,id = self.id;
            if (containsID.length > 0) {
                containsID.html(self.view());
                $(".keyboard-wrap-layer").css(self.css);
            }
            if (isAndroid) {
                var obj = $("#" + self.id);
                var layerObj = obj.parents(".keyboard-wrap").find(".keyboard-wrap-layer");
                if (!obj.val()) {
                    layerObj.addClass("keyboard-placeholder");
                    layerObj.html(obj.attr("placeholder"));//替换成...
                }
            }
        },
        bindEvents: function(options) {//初始化数据绑定
            var self = this, opts = options,containsID = self.containsID;
            //绑定input blur事件  trigger 使用
            self.body.on("blur keyboardBlur", "input#" + self.id, (function() {
                return function(event) {
                    self.handlers.blur.apply(self, [event, $(this)]);
                };
            })());
            //绑定input focus事件 trigger 使用
            self.body.on("focus keyboardFocus", "input#" + self.id, (function() {
                return function(event) {
                    self.handlers.focus.apply(self, [event, $(this)]);
                };
            })());
            if (isAndroid) {
                self.body.off("tap.keyboard").on("tap.keyboard", (function() {
                    return function(event) {
                        self.handlers.androidTap.apply(self, [event, $(this)]);
                    };
                })());
            }
        },
        handlers: {
            focus: function(event, obj) {//触发焦点处理
                var self = this,type = self.type || "1",selfObj = $("#" + self.id),
                defaultValue = selfObj.val() || "",maxLength = self.maxLength;
                self.focus && self.focus(obj);
                Hyperion.actions.keyboard({
                        type: type,
                        params: {
                            defaultValue: defaultValue,
                            maxLength: maxLength
                        },
                        keyPressCallback: function(value) {
                            var val = value || "";
                            selfObj.val(val);
                            if (isAndroid) {
                                var character = "\u2022";
                                var layerObj = selfObj.parents(".keyboard-wrap").find(".keyboard-wrap-layer");
                                if (!selfObj.val()) {
                                    layerObj.addClass("keyboard-placeholder");
                                    layerObj.html(obj.attr("placeholder"));//替换成...
                                } else {
                                    layerObj.removeClass("keyboard-placeholder");
                                    layerObj.html(val.replace(/./g, character));//替换成...
                                }
                            }
                            self.press && self.press(val, obj);
                        },
                        completeCallback: function (value) {
                            var val = value || "";
                            selfObj.val(val);
                            if (isAndroid) {
                                var character = "\u2022";
                                var layerObj = selfObj.parents(".keyboard-wrap").find(".keyboard-wrap-layer");
                                if (!selfObj.val()) {
                                    layerObj.addClass("keyboard-placeholder");
                                    layerObj.html(obj.attr("placeholder"));//替换成...
                                } else {
                                    layerObj.removeClass("keyboard-placeholder");
                                    layerObj.html(val.replace(/./g, character));//替换成...
                                }
                            }
                            self.press && self.press(val, obj);
                        }
                    });
            },
            androidTap: function (event) {//android失去焦点
                var self = this;
                var target = event.srcElement || event.target;
                var targetObj = $(target);
                var otherObj = null;
                var keyBoardList = $(".keyboard-wrap-layer");
                if (targetObj.hasClass("keyboard-wrap-layer")) {
                    console.log(targetObj.attr("class") + "true");
                    $.each(keyBoardList, function(index, obj) {
                        var that = $(obj);
                        if (targetObj.attr("class") !== that.attr("class") && that.attr("data-focus") === "1") {
                            that.attr("data-focus", "0");
                            that.parents(".keyboard-wrap").find("input").trigger("keyboardBlur");
                        }
                    });
                    targetObj.attr("data-focus", "1");
                    targetObj.parents(".keyboard-wrap").find("input").trigger("keyboardFocus");
                } else {
                    $.each(keyBoardList, function(index, obj) {
                        var that = $(obj);
                        if (that.attr("data-focus") === "1") {
                            that.attr("data-focus", "0");
                            that.parents(".keyboard-wrap").find("input").trigger("keyboardBlur");
                        }
                    });
                }
            },
            blur: function(event, obj) {//ios失去焦点
                var self = this;
                self.blur && self.blur(obj);
                Hyperion.actions.closeKeyboard();
            }
        }
    };
    return keyboard;
});
