require([
        'iscroll'
    ],
    function() {
        var calendar = FView.extend({
            list: {},
            events: {
                'tap .head-list li': 'head_Tap',//起始时间
                'tap #beginCalendar p': 'beginC_Tap'
            },
            init: function() {
                var self = this;
                Hyperion.actions.setHeader({
                    title: '交易记录',
                    isBack: true,
                    backCallback: function() {
                        Hyperion.actions.back();
                    },
                    isClose: false
                });
                /**
                 * 对Date的扩展，将 Date 转化为指定格式的String * 月(M)、日(d)、12小时(h)、24小时(H)、分(m)、秒(s)、周(E)、季度(q)
                 * 可以用 1-2 个占位符 * 年(y)可以用 1-4 个占位符，毫秒(S)只能用 1 个占位符(是 1-3 位的数字)
                 * eg:
                 * (new Date()).format("yyyy-MM-dd hh:mm:ss.S")==> 2006-07-02 08:09:04.423
                 * (new Date()).format("yyyy-MM-dd E HH:mm:ss") ==> 2009-03-10 二 20:09:04
                 * (new Date()).format("yyyy-MM-dd EE hh:mm:ss") ==> 2009-03-10 周二 08:09:04
                 * (new Date()).format("yyyy-M-d h:m:s.S") ==> 2006-7-2 8:9:4.18
                 * (new Date()).format("yyyy-MM-dd hh:mm:ss") ==> 2015-04-21 14:22
                 * @param fmt 格式化字符串
                 * @returns {*} 格式化后时间
                 */
                Date.prototype.format = function (fmt) {
                    var o = {
                        "M+": this.getMonth() + 1, //月份
                        "d+": this.getDate(), //日
                        "h+": this.getHours() % 12 === 0 ? 12 : this.getHours() % 12, //小时
                        "H+": this.getHours(), //小时
                        "m+": this.getMinutes(), //分
                        "s+": this.getSeconds(), //秒
                        "q+": Math.floor((this.getMonth() + 3) / 3), //季度
                        "S": this.getMilliseconds() //毫秒
                    };
                    var week = {
                        "0": "/u65e5",
                        "1": "/u4e00",
                        "2": "/u4e8c",
                        "3": "/u4e09",
                        "4": "/u56db",
                        "5": "/u4e94",
                        "6": "/u516d"
                    };
                    if (/(y+)/.test(fmt)) {
                        fmt = fmt.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
                    }
                    if (/(E+)/.test(fmt)) {
                        fmt = fmt.replace(RegExp.$1, ((RegExp.$1.length > 1) ? (RegExp.$1.length > 2 ? "/u661f/u671f" : "/u5468") : "") + week[this.getDay() + ""]);
                    }
                    for (var k in o) {
                        if (new RegExp("(" + k + ")").test(fmt)) {
                            fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
                        }
                    }
                    return fmt;
                };
                /**
                 * 返回一个事件的前几年（月、日）
                 * @param num
                 * @param type 'year', 'month', 'day', 'hour', 'minutes', 'seconds'
                 * @returns {string}
                 */
                Date.prototype.before = function (num, type) {
                    type = type || 'day';
                    var tmp,
                        value;
                    switch (type) {
                        case 'year':
                            tmp = this.getFullYear() - num;
                            value = this.setYear(tmp);
                            break;
                        case 'month':
                            tmp = this.getMonth() - num;
                            value = this.setMonth(tmp);
                            break;
                        case 'day':
                            tmp = this.getDate() - num;
                            value = this.setDate(tmp);
                            break;
                        case 'hour':
                            tmp = this.getHours() - num;
                            value = this.setHours(tmp);
                            break;
                        case 'minutes':
                            tmp = this.getMinutes() - num;
                            value = this.setMinutes(tmp);
                            break;
                        case 'seconds':
                            tmp = this.getSeconds() - num;
                            value = this.setSeconds(tmp);
                            break;
                        default:
                            break;
                    }
                    value = this.format('yyyy/MM/dd hh:mm:ss');
                    return value;
                };
                /**
                 * 返回一个事件的后几年（月、日）
                 * @param num
                 * @param type 'year', 'month', 'day', 'hour', 'minutes', 'seconds'
                 * @returns {string}
                 */
                Date.prototype.after = function (num, type) {
                    type = type || 'day';
                    var tmp,
                        value;
                    switch (type) {
                        case 'year':
                            tmp = this.getFullYear() + num;
                            value = this.setYear(tmp);
                            break;
                        case 'month':
                            tmp = this.getMonth() + num;
                            value = this.setMonth(tmp);
                            break;
                        case 'day':
                            tmp = this.getDate() + num;
                            value = this.setDate(tmp);
                            break;
                        case 'hour':
                            tmp = this.getHours() + num;
                            value = this.setHours(tmp);
                            break;
                        case 'minutes':
                            tmp = this.getMinutes() + num;
                            value = this.setMinutes(tmp);
                            break;
                        case 'seconds':
                            tmp = this.getSeconds() + num;
                            value = this.setSeconds(tmp);
                            break;
                        default:
                            break;
                    }
                    value = self.format('yyyy/MM/dd hh:mm:ss');
                    return value;
                };
                /**
                 * 返回一个带上午或者是下午的时间格式字符串;
                 * @param time 时间戳
                 * @return 带上午或者是下午的时间格式字符串
                 */
                Date.prototype.formatAmPm = function (time) {
                    var date = (time !== undefined && new Date(time) != 'Invalid Date') ? new Date(time) : new Date(),
                        hours = date.getHours(),
                        returnVal = hours > 12 ? '下午' : '上午',
                        tmp = date.format('yyyy/MM/dd hh:mm:ss').split(' ');

                    returnVal = tmp[0] + ' ' + returnVal + tmp[1];
                    return returnVal;
                };
                //计算某年某月有多少天
                Date.prototype.getDaysInMonth = function() {
                    return new Date(this.getFullYear(), this.getMonth() + 1, 0).getDate();
                };
                //计算某月1号是星期几
                Date.prototype.getWeekInMonth = function() {
                    var month = this.getMonth() + 1;
                    var tmp = this.getFullYear() + '/' + month + '/' + '01';
                    var day = new Date(tmp).getDay();
                    return new Date(tmp).getDay();
                };
                Date.prototype.getParseMonth = function (m) {
                    return ['一', '二', '三', '四', '五', '六', '七', '八', '九', '十', '十一', '十二'][m];
                };
                //计算年某月的最后一天日期
                Date.prototype.getLastDayInMonth = function() {
                    return new Date(this.getFullYear(), this.getMonth() + 1, this.getDaysInMonth(year, month));
                };
                Date.prototype.getMonthLastDay = function() {
                    var month = this.getMonth() + 1;
                    var tmp = this.getFullYear() + '/' + month + '/' + this.getDaysInMonth();
                    var day = new Date(tmp).getDay();
                    return new Date(tmp).getDay();
                };
                //交易记录带过来数据
                self.list = self.query;
                var a = self.list.startTimeDays;
                var b = a.substring(0, 4);
                var c = a.substring(4, 6);
                var d = a.substring(6, 8);
                var a1 = self.list.endTimeDays;
                var b1 = a1.substring(0, 4);
                var c1 = a1.substring(4, 6);
                var d1 = a1.substring(6, 8);
                var startDate = b + '/' + c + '/' + d;
                var endDate = b1 + '/' + c1 + '/' + d1;
                console.log('===' + startDate + ',===' + endDate);
                console.log(self.list);
                /*距离多少天加多少个<p class="later-day">3</p>     开始日期要多加一个<p class="aBefore"></p>
                 结束日期 前一天要加<p class="aAfter"></p>
                 获取开始跟结束的距离*/
                var days = self.getTimeDifference(new Date(startDate), new Date(endDate)).days;

                var start = $('#start');
                var end = $('#end');
                var date = new Date().format('yyyy/MM');
                var state = 1;
                var dateTables = '';
                var contextBox = $('#beginCalendar'), tmpDate = null, calcVal = 1, calendarEls = null;
                var fillDate = function (options) {

                    var beginDate = null, curDayText = "";
                    calendarEls = $(".calendar-container .calendar");
                    calcVal = options.appendType === 'append' ? 1 : -1;
                    if (options.isInit === undefined) {
                        if (calcVal === -1) {
                            beginDate = calendarEls.eq(0).data('datestring');
                        } else {
                            beginDate = calendarEls.eq(calendarEls.length - 1).data('datestring');
                        }
                        beginDate += '/01';
                        tmpDate = new Date(beginDate);
                        tmpDate.setDate(1);
                        tmpDate.setMonth(tmpDate.getMonth() + calcVal);
                    } else {
                        calendarEls.remove();
                        options.beginDate = (options.beginDate + "").replace(/\-/g, '/');
                        beginDate = options.beginDate;
                        curDayText = new Date(beginDate).format("dd");
                        tmpDate = new Date(beginDate);
                        tmpDate.setDate(1);
                    }
                    dateTables = self.buildCalendar(tmpDate.format('yyyy/MM/dd'), curDayText);

                    /* var dateTitle = beginDate.split("-")[0]+"年"+beginDate.split("-")[1]+"月";
                     var dateString = beginDate.split("-")[0]+"/"+beginDate.split("/")[1];*/

                    contextBox[options.appendType].call(contextBox, "<div class='item current calendar' data-datestring='" + tmpDate.format("yyyy/MM") + "'><h1 class='title'>" + tmpDate.format("yyyy年MM月") + "</h1>" + dateTables + "</div>");
                    self.myscroll.refresh();
                    beginDate = tmpDate.format('yyyy/MM/dd');
                };


                var self = this, startY = 0, endY = 0;
                this.myscroll = new iScroll("wrapper", {
                    momentum: true,//开启拖到惯性
                    hScroll: false, // 不允许水平滚动
                    vScroll: true,   //允许垂直滚动
                    hScrollbar: false,  //不显示滚动条
                    vScrollbar: false, // 不显示垂直滚动条
                    bounce: true,   //是否超过实际位置反弹
                    lockDirection: true, //当水平或垂直拖到时是否锁定另一边拖到
                    y: -300,
                    //    x:$_.calculatorData.scale,
                    snap: false, //是否可以捕捉元素
                    topOffset: 10,
                    onScrollStart: function() { //开始滚动的回调
                        console.log(arguments);
                        endY = 0;
                        startY = this.y;
                    },
                    onScrollMove: function (e) { //内容移动的回调
                        endY = this.y;
                    },
                    onScrollEnd: function() { //滚动完成后的回调

                        console.log('startY:' + startY + " endY:" + endY);

                        var isPullUp = startY <= endY, isPullDown = startY > endY;
                        var pullVal = Math.abs(Math.abs(startY) - Math.abs(endY));
                        console.log("pull" + (isPullUp ? 'up' : 'down') + "   " + pullVal);
                        if (isPullUp || isPullDown) {
                            fillDate({appendType: isPullUp ? 'prepend' : 'append'});
                            self.myscroll.refresh();//重新渲染界面
                        }
                        startY = 0;
                        endY = 0;
                    }
                });
                //结束时期初始化
                fillDate({appendType: 'append', isInit: true, beginDate: startDate});
                fillDate({appendType: 'append'});
                fillDate({appendType: 'append'});
                //$(".head-list li").eq(0).trigger("tap");
            },

            handlers: {
                'head_Tap': function (e) {
                    var target = e.target,
                        $target = $(target),
                        self = this;
                    var cData = self.list.startDate;
                    if ($(this).index() === 1) {
                        cData = self.list.endDate;
                    }
                    $target.addClass("active").siblings().removeClass("active");
                },
                'beginC_Tap': function (e, el) {
                    var self = this;
                    var target = e.target,
                        $target = $(target),
                        startTime = null, startDay = null,
                        endTime = null, endDay = null;
                    console.log($target);
                    $('p.aBefore,p.aAfter').remove();
                    $(".calendar p").removeClass("later-day");

                    if ($('.time-list.start').hasClass('active')) {//起始时间含有active
                        $(".calendar p").removeClass("current-day");
                        $target.addClass("current-day");
                    }

                    if ($('.time-list.end').hasClass('active')) {//结束时间含有active
                        $(".calendar p").removeClass("current-dayEnd");
                        $target.addClass("current-dayEnd");
                    }

                    startTime = $(".calendar p.current-day");
                    endTime = $(".calendar p.current-dayEnd");
                    startDay = startTime.parents(".calendar").attr('data-datestring') + '/' + startTime.html();//获取用户选择开始日期 xxxx/xx/xx
                    if (startDay) {
                        $('.time-list.end').addClass('active');
                        $('.time-list.start').removeClass('active');
                        endDay = endTime.parents(".calendar").attr('data-datestring') + '/' + endTime.html();//获取用户选择结束日期 xxxx/xx/xx
                    }
                    var diffMonths = self.getTimeDifference(new Date(startDay), new Date(endDay)).months;
                    console.log(diffMonths);

                    if (startTime.html() && endTime.html()) {
                        days = self.getTimeDifference(new Date(startDay), new Date(endDay)).days;//计算开始日期和结束日期的天数
                        startTime.parent().append('<p class="aBefore"></p>');
                        endTime.parent().append('<p class="aAfter"></p>');

                        // 判断起始时间和截止时间为同月的情况
                        if (diffMonths <= 1) {//等于0表示同月
                            var tmpStart = false,
                                tmpEnd = false;
                            startTime.parents(".calendar").find('p').each(function() {
                                if ($(this).hasClass('current-day')) {
                                    tmpStart = true;
                                }
                                if ($(this).hasClass('current-dayEnd')) {
                                    tmpEnd = true;
                                }
                                if (tmpStart && !tmpEnd) {
                                    $(this).addClass('later-day');
                                }
                            });
                        } else {
                            for (var i = 0; i < $('.item').length; i++) {
                                if (self.getTimeDifference(new Date(startDay), new Date($('.item').eq(i).data('datestring') + '/01')).months > 0 && self.getTimeDifference(new Date($('.item').eq(i).data('datestring') + '/01'), new Date(endDay)).months > 0) {
                                    $('.item').eq(i).find('p').addClass('later-day');
                                }
                            }
                        }
                        // 判断截止时间不为当月
                        if (new Date(startDay).getMonth() != new Date(endDay).getMonth()) {
                            var tmpStart = false;
                            startTime.parents(".calendar").find('p').each(function() {
                                if ($(this).hasClass('current-day')) {
                                    tmpStart = true;
                                }
                                if (tmpStart) {
                                    $(this).addClass('later-day');
                                }
                            });
                            var tmpEnd = true;
                            endTime.parents('.calendar').find('p').each(function() {
                                if ($(this).hasClass('current-dayEnd')) {
                                    tmpEnd = false;
                                }
                                if (tmpEnd) {
                                    $(this).addClass('later-day');
                                }
                            });
                        }
                        //日期格式 xxxx/xx/xx
                        var a1 = startDay;
                        console.log(a1);
                        var a2 = a1.substring(0, 4);//年
                        var a3 = a1.substring(5, 7);//月
                        var a4 = a1.substring(8, 10);//日
                        //var a5 = a3 < 10 ? '0' + a3 : a3;
                        var a6 = a4 < 10 ? '0' + a4 : a4;
                        var startDateTime = a2 + '/' + a3 + '/' + a6;
                        var b1 = endDay;
                        console.log(b1);
                        var b2 = b1.substring(0, 4);//年
                        var b3 = b1.substring(5, 7);//月
                        var b4 = b1.substring(8, 10);//日
                        //var b5 = b3 < 10 ? '0' + b3 : b3;
                        var b6 = b4 < 10 ? '0' + b4 : b4;
                        var endDateTime = b2 + '/' + b3 + '/' + b6;

                        if (days > 90) {
                            Hyperion.actions.tip({text: "查询跨度不能超过90天"});
                            el.removeClass('current-dayEnd');
                            $('.form p').removeClass('later-day').removeClass('aAfter').removeClass('aBefore');
                        } else if (days < 0) {
                            Hyperion.actions.tip({text: "请选择大于起始时间的日期"});
                            el.removeClass('current-dayEnd');
                            $('.form p').removeClass('later-day').removeClass('aAfter').removeClass('aBefore');
                        } else {
                            Hyperion.actions.setData({
                                    name: 'TimeDate',
                                    value: {
                                        'startDateT_': startDateTime,//开始时间
                                        'endDateT_': endDateTime//结束时间
                                    }
                                },
                                function() {
                                    Hyperion.actions.back();
                                });
                        }
                    }
                }
            },
            //算开始跟结束的天数
            'getTimeDifference': function (beginDate, endDate) {
                var arr = [];
                arr.years = arr.months = arr.days = arr.hours = arr.mins = arr.diffTime = 0;
                if (beginDate === null || beginDate === "" || beginDate === undefined) {
                    return arr;
                }
                if (endDate === null || endDate === "" || endDate === undefined) {
                    endDate = new Date();
                }

                var diffTime = endDate.getTime() - beginDate.getTime();
                arr.years = endDate.getFullYear() - beginDate.getFullYear();
                arr.months = endDate.getMonth() - beginDate.getMonth() + arr.years * 12;
                arr.days = Math.floor(diffTime / (24 * 3600 * 1000));
                arr.hours = Math.floor(diffTime / (3600 * 1000));
                arr.mins = Math.floor(diffTime / (60 * 1000));
                arr.diffTime = diffTime;
                return arr;
            },
            /**
             * 生成日历
             * @eg: document.getElementsByTagName('body')[0].innerHTML = func1()
             * @param dateString 必须传入时间格式
             * @returns {string} 生成的HTML字符串
             * @daysApart {number}  差的天数
             */
            buildCalendar: function (dateString, currentDay) {
                console.log(dateString);
                var date = (dateString) ? new Date(dateString) : new Date();
                var currentLength = date.getDaysInMonth();  //当前月有多少天
                var currentFirst = date.getWeekInMonth(); //当前月第一天星期几
                var currentEnd = date.getMonthLastDay(); //当前月最后一天星期几
                var emptyPreBlock = currentFirst; //前面需要空多少格
                var emptyEndBlock = 6 - currentEnd; //后面需要空多少格
                var sumBlock = emptyEndBlock + emptyPreBlock + currentLength; //总格数
                var renderStr = ''; // 渲染Html String
                var j = 1;
                var currentClass = '';

                renderStr = '<table class="form"><tr><th>周日</th><th>周一</th><th>周二</th><th>周三</th><th>周四</th><th>周五</th> <th>周六</th></tr>';
                for (var i = 1; i <= sumBlock; i++) {

                    if (i % 7 === 1) {
                        renderStr += "<tr>";
                    }
                    if (i <= emptyPreBlock) {
                        // 前面的空格
                        renderStr += "<td></td>";
                    } else if (i > currentLength + emptyPreBlock) {
                        // 后面的空格
                        renderStr += "<td></td>";
                    } else {
                        console.log(new Date(dateString).format('yyyy-MM-dd'));
                        //开始时间样式
                        currentClass = Number(currentDay) === j ? "current-day" : "";
                        renderStr += "<td><div><p class='" + currentClass + "'>" + j + "</p></div></td>";
                        j++;
                    }
                    if (i % 7 === 0) {
                        // 换行
                        renderStr += "</tr>";
                    }
                }
                renderStr += '</table>';
                return renderStr;
            }
        });
        new calendar();
    });